summaryrefslogtreecommitdiff
path: root/test/files
diff options
context:
space:
mode:
Diffstat (limited to 'test/files')
-rw-r--r--test/files/run/hashCodeBoxesRunTime.scala (renamed from test/files/run/hashCodeScalaRunTime.scala)10
-rw-r--r--test/files/run/hashhash.scala8
2 files changed, 5 insertions, 13 deletions
diff --git a/test/files/run/hashhash.scala b/test/files/run/hashhash.scala
index f9fc067398..dc31df8cfa 100644
--- a/test/files/run/hashhash.scala
+++ b/test/files/run/hashhash.scala
@@ -9,15 +9,7 @@ object Test {
val x = (BigInt(1) << 64).toDouble
val y: Any = x
- val f: Float = x.toFloat
- val jn: java.lang.Number = x
- val jf: java.lang.Float = x.toFloat
- val jd: java.lang.Double = x
assert(x.## == y.##, ((x, y)))
- assert(x.## == f.##, ((x, f)))
- assert(x.## == jn.##, ((x, jn)))
- assert(x.## == jf.##, ((x, jf)))
- assert(x.## == jd.##, ((x, jd)))
}
}
diff --git a/test/files/run/hashCodeScalaRunTime.scala b/test/files/run/hashCodeBoxesRunTime.scala
index e352af95f1..081a73376e 100644
--- a/test/files/run/hashCodeScalaRunTime.scala
+++ b/test/files/run/hashCodeBoxesRunTime.scala
@@ -1,23 +1,23 @@
// This only tests direct access to the methods in ScalaRunTime,
// not the whole scheme.
object Test
{
import java.{ lang => jl }
- import scala.runtime.ScalaRunTime.{ hash }
+ import scala.runtime.BoxesRunTime.{ hashFromNumber, hashFromObject }
def allSame[T](xs: List[T]) = assert(xs.distinct.size == 1, "failed: " + xs)
def mkNumbers(x: Int): List[Number] =
List(x.toByte, x.toShort, x, x.toLong, x.toFloat, x.toDouble)
- def testLDF(x: Long) = allSame(List[Number](x, x.toDouble, x.toFloat) map hash)
+ def testLDF(x: Long) = allSame(List[Number](x, x.toDouble, x.toFloat) map hashFromNumber)
def main(args: Array[String]): Unit = {
List(Byte.MinValue, -1, 0, 1, Byte.MaxValue) foreach { n =>
- val hashes = mkNumbers(n) map hash
+ val hashes = mkNumbers(n) map hashFromNumber
allSame(hashes)
if (n >= 0) {
- val charCode = hash(n.toChar: Character)
+ val charCode = hashFromObject(n.toChar: Character)
assert(charCode == hashes.head)
}
}
@@ -1,23 +1,23 @@
-// This only tests direct access to the methods in ScalaRunTime,
+// This only tests direct access to the methods in BoxesRunTime,
// not the whole scheme.
object Test